demo.all: Emu segment list
Description
Segment list of the demo database that is part of the Emu system. It is
the result of a database query, that searched all segments at level
Phonetic.
Format
First Column labels Second start time of the segment Third end time
of the segment Fourth utterance name of the utterance the segment was foundDetails
A segment list is created via query.