demo.all.f0: F0 track data for segment list demo.vowels
Description
A track list of the demo database that is part of the Emu system. It is
the result of get F0 data for the segment list demo.vowels (see
data(demo.vowels)).
Format
An object with \$index, \$ftime and \$data index: a two columned matrix with the range of the \$data rows that belong
to the segment ftime: a two columned matrix with the times marks of the
segment data: a one columned matrix with the F0 values