demo.all.fm: Formant track data for segment list demo.vowels
Description
A track list of the demo database that is part of the Emu system. It is
the result of get fm data for the segment list demo.vowels (see
data(demo.vowels)).
Format
index: a two columned matrix with the range of the \$data rows that
belong to the segment ftime: a two columned matrix with the times marks of
the segment data: a three columned matrix with the formant values of the
first three formants for each segment