demo.all.rms: Emu track data for a rms track for segment list demo.all
Description
A track list of the demo database that is part of the Emu system. It is
the result of get rms data for the segment list demo.all (data(demo.all)).
Format
A object with \$index, \$ftime and \$data index: a two columned matrix with the range of the \$data rows that belong
to the segment ftime: a two columned matrix with the times marks of the
segment data: a vector with the rms data