Learn R Programming

emuR (version 0.1.6)

euclidean: Find the inter-euclidean distance for a data matrix

Description

Finds the inter-euclidean distance for a data matrix

Usage

euclidean(data, m = 1, n = ncol(data))

Arguments

data
A vector or matrix of numerical data.
m
The first column of data to be used in the distance calculation.
n
The last column of data to be used in the distance calculation.

Value

  • Calculates the euclidean distance between successive rows of the matrix based on columns m:n.

See Also

steady

Examples

Run this code
euclidean(cbind(c(1,2,3,4), c(2,3,2,2)))

Run the code above in your browser using DataLab