Rdocumentation
powered by
Learn R Programming
emuR (version 0.1.8)
expand_labels: Label each data sample
Description
Labels each data sample
Usage
expand_labels(indvals, labs)
Arguments
indvals
Index component of a trackdata object as returned by
frames
, or
track
.
labs
A label vector parallel to
indvals
.
Value
Returns a vector of labels, one for each row in the data matrix that corresponds to
indvals
.
See Also
frames, track