Learn R Programming

emuR (version 0.1.7)

read.emusegs: Create an Emu segment list from a file

Description

Create an Emu segment list from a file saved by the Emu query tools.

Usage

read.emusegs(file)

Arguments

file
The name of the file to read

Value

  • An Emu segment list.

Details

Reads segment lists created by programs external to R/Splus and stored in text files on disk.

See Also

query

Examples

Run this code
## create a segment list file and write it out
# seglist.txt <- "database:demo"\\
# query:Phonetic=vowel\\
# type:segment\\
#\\
# @:	3059.65	3343.65	msdjc001\\
# e:	5958.55	6244.55	msdjc002\\
# @u	8984.75	9288.75	msdjc003\\
# A	11880.8	12184.8	msdjc004\\
# E	17188.3	17366.4	msdjc005\\
# ei	20315.2	20655.2	msdjc006"

cat(seglist.txt, file="seglist.txt")

# now read it back as a segment list
segs <- read.emusegs("seglist.txt")
segs
## and clean up
unlink("seglist.txt")

Run the code above in your browser using DataLab