## Not run:
#
# ##################################
# # prerequisite: loaded ae emuDB
# # (see ?load_emuDB for more information)
#
# ## Downward requery: find 'Phoneme' sequences of all words 'beautiful' (of level 'Text')
# ## Note that the resulting segments consists of phoneme sequences and have therefore
# ## the same length as the word segments.
#
# sl1 = query(ae, "Text == beautiful")
# requery_hier(ae, sl1, level = "Phoneme")
#
# ## Upward requery: find all word segments that dominate a 'p' on level 'Phoneme'
# ## Note that the resulting segments are larger than the input segments,
# ## because they contain the complete words.
#
# sl1 = query(ae, "Phonetic == p")
# requery_hier(ae, sl1, level = 'Text')
#
# ## Why is there a 'p' the word 'emphazised'? Requery the whole words back down to 'Phoneme' level:
#
# requery_hier(ae, sl1, level = 'Phoneme')
#
# ## ... because of 'stop epenthesis' a 'p' is inserted between 'm' and 'f'
#
# ## Combined requery: last phonemes of all words beginning with 'an'.
# ## Note that we use a regular expression 'an.*' (EQL operator '=~') in the query.
#
# sl1=query(ae, "Text =~ an.*")
# requery_seq(ae, requery_hier(ae, sl1, level = 'Phoneme'), offsetRef = 'END')
#
# ## End(Not run)
Run the code above in your browser using DataLab