summary.emuDBhandle: Print summary of loaded EMU database (emuDB).
Description
Gives an overview of an EMU database.
Prints database name, UUID, base directory path, session and bundle count and informations about signal track, annotation level, attribute and link definitions.
Usage
## S3 method for class 'emuDBhandle':
summary(object, ...)