Learn R Programming

emuR (version 0.1.7)

create_emuRdemoData: Create demo data for the emuR package

Description

Create a folder within the folder specified by the dir argument called emuR_demoData. This folder contains the folders:
  • ae_emuDB:
{Containing an emuDB that adheres to the new format specification (as expected by the load_emuDB function). See vignette(emuDB) for more information on this database format.} BPF_collection:{Containing a BAS Patitur Format (BPF) file collection (as expected by the convert_BPFCollection function)} legacy_ae:{Containing a legacyEmuDB (as expected by the convert_legacyEmuDB function)} TextGrid_collection:{Containing a TextGrid file collection (as expected from the convert_TextGridCollection function)}

Usage

create_emuRdemoData(dir = tempdir(), precache = FALSE)

Arguments

dir
directory to create demo data in (default= tempdir())
precache
creates an on-file-system cache for the ae emuDB to allow fast loading (see load_emuDB for details about the emuDB file cache)

Examples

Run this code
# create demo data directory in directory
# provided by the tempdir function
create_emuRdemoData(dir = tempdir())

Run the code above in your browser using DataLab