index: a two columned matrix with the range of the $data rows that belong to the segment ftime: a two columned matrix with the times marks of the segment data: a one columned matrix with the F0 values
get_trackdata function.demo.all.rms segmentlist
trackdata