index: a two columned matrix with the range of the $data rows that belong to the segment ftime: a two columned matrix with the times marks of the segment data: a vector with the rms data
get_trackdata function.demo.vowels.fm segmentlist
trackdata